==> ember-cli-tailwind-0.1.0.tgz: package/blueprints/ember-cli-tailwind/files/__root__/styles/tailwind/config/tailwind.js <==
'use strict';
/*eslint-env node */

let colors = require('./colors');
let screens = require('./screens');
let fonts = require('./fonts');
let textSizes = require('./text-sizes');
let fontWeights = require('./font-weights');
let leading = require('./line-height');
let tracking = require('./letter-spacing');
let borderWidths = require('./border-widths');
let borderRadius = require('./border-radius');
let width = require('./width');
let height = require('./height');
let minWidth = require('./min-width');
let minHeight = require('./min-height');
let maxWidth = require('./max-width');
let maxHeight = require('./max-height');
let padding = require('./padding');
let margin = require('./margin');
let negativeMargin = require('./negative-margin');
let shadows = require('./shadows');
let zIndex = require('./z-index');
let opacity = require('./opacity');
let svgFill = require('./svg-fill');
let svgStroke = require('./svg-stroke');

module.exports = {

  colors,
  screens,
  fonts,
  textSizes,
  fontWeights,
  leading,
  tracking,
  textColors: colors,
  backgroundColors: colors,
  borderWidths,
  borderColors: Object.assign({ default: colors['grey-light'] }, colors),
  borderRadius,
  width,
  height,
  minWidth,
  minHeight,
  maxWidth,
  maxHeight,
  padding,
  margin,
  negativeMargin,
  shadows,
  zIndex,
  opacity,
  svgFill,
  svgStroke,

  modules: {
    appearance: ['responsive'],
    backgroundAttachment: ['responsive'],
    backgroundColors: ['responsive', 'hover'],
    backgroundPosition: ['responsive'],
    backgroundRepeat: ['responsive'],
    backgroundSize: ['responsive'],
    borderColors: ['responsive', 'hover'],
    borderRadius: ['responsive'],
    borderStyle: ['responsive'],
    borderWidths: ['responsive'],
    cursor: ['responsive'],
    display: ['responsive'],
    flexbox: ['responsive'],
    float: ['responsive'],
    fonts: ['responsive'],
    fontWeights: ['responsive', 'hover'],
    height: ['responsive'],
    leading: ['responsive'],
    lists: ['responsive'],
    margin: ['responsive'],
    maxHeight: ['responsive'],
    maxWidth: ['responsive'],
    minHeight: ['responsive'],
    minWidth: ['responsive'],
    negativeMargin: ['responsive'],
    opacity: ['responsive', 'hover'],
    overflow: ['responsive'],
    padding: ['responsive'],
    pointerEvents: ['responsive'],
    position: ['responsive'],
    resize: ['responsive'],
    shadows: ['responsive'],
    svgFill: [],
    svgStroke: [],
    textAlign: ['responsive'],
    textColors: ['responsive', 'hover'],
    textSizes: ['responsive'],
    textStyle: ['responsive', 'hover'],
    tracking: ['responsive'],
    userSelect: ['responsive'],
    verticalAlign: ['responsive'],
    visibility: ['responsive'],
    whitespace: ['responsive'],
    width: ['responsive'],
    zIndex: ['responsive'],
  },

  /*
  |-----------------------------------------------------------------------------
  | Advanced Options         https://tailwindcss.com/docs/configuration#options
  |-----------------------------------------------------------------------------
  |
  | Here is where you can tweak advanced configuration options. We recommend
  | leaving these options alone unless you absolutely need to change them.
  |
  */

  options: {
    prefix: '',
    important: false,
    separator: ':',
  },

}

==> ember-cli-tailwind-0.2.5.tgz: package/blueprints/ember-cli-tailwind/files/__root__/styles/tailwind/config/tailwind.js <==
'use strict';
/*eslint-env node */

let colors = require('../colors');
let screens = require('../screens');
let fonts = require('../fonts');
let textSizes = require('../text-sizes');
let fontWeights = require('../font-weights');
let leading = require('../line-height');
let tracking = require('../letter-spacing');
let borderWidths = require('../border-widths');
let borderRadius = require('../border-radius');
let width = require('../width');
let height = require('../height');
let minWidth = require('../min-width');
let minHeight = require('../min-height');
let maxWidth = require('../max-width');
let maxHeight = require('../max-height');
let padding = require('../padding');
let margin = require('../margin');
let negativeMargin = require('../negative-margin');
let shadows = require('../shadows');
let zIndex = require('../z-index');
let opacity = require('../opacity');
let svgFill = require('../svg-fill');
let svgStroke = require('../svg-stroke');

module.exports = {

  colors,
  screens,
  fonts,
  textSizes,
  fontWeights,
  leading,
  tracking,
  textColors: colors,
  backgroundColors: colors,
  borderWidths,
  borderColors: Object.assign({ default: colors['grey-light'] }, colors),
  borderRadius,
  width,
  height,
  minWidth,
  minHeight,
  maxWidth,
  maxHeight,
  padding,
  margin,
  negativeMargin,
  shadows,
  zIndex,
  opacity,
  svgFill,
  svgStroke,

  modules: {
    appearance: ['responsive'],
    backgroundAttachment: ['responsive'],
    backgroundColors: ['responsive', 'hover'],
    backgroundPosition: ['responsive'],
    backgroundRepeat: ['responsive'],
    backgroundSize: ['responsive'],
    borderColors: ['responsive', 'hover'],
    borderRadius: ['responsive'],
    borderStyle: ['responsive'],
    borderWidths: ['responsive'],
    cursor: ['responsive'],
    display: ['responsive'],
    flexbox: ['responsive'],
    float: ['responsive'],
    fonts: ['responsive'],
    fontWeights: ['responsive', 'hover'],
    height: ['responsive'],
    leading: ['responsive'],
    lists: ['responsive'],
    margin: ['responsive'],
    maxHeight: ['responsive'],
    maxWidth: ['responsive'],
    minHeight: ['responsive'],
    minWidth: ['responsive'],
    negativeMargin: ['responsive'],
    opacity: ['responsive', 'hover'],
    overflow: ['responsive'],
    padding: ['responsive'],
    pointerEvents: ['responsive'],
    position: ['responsive'],
    resize: ['responsive'],
    shadows: ['responsive'],
    svgFill: [],
    svgStroke: [],
    textAlign: ['responsive'],
    textColors: ['responsive', 'hover'],
    textSizes: ['responsive'],
    textStyle: ['responsive', 'hover'],
    tracking: ['responsive'],
    userSelect: ['responsive'],
    verticalAlign: ['responsive'],
    visibility: ['responsive'],
    whitespace: ['responsive'],
    width: ['responsive'],
    zIndex: ['responsive'],
  },

  /*
  |-----------------------------------------------------------------------------
  | Advanced Options         https://tailwindcss.com/docs/configuration#options
  |-----------------------------------------------------------------------------
  |
  | Here is where you can tweak advanced configuration options. We recommend
  | leaving these options alone unless you absolutely need to change them.
  |
  */

  options: {
    prefix: '',
    important: false,
    separator: ':',
  },

}
